@@ -1,3 +1,4 @@
+import copy
 import inspect
 import re
 from typing import List, Union, Optional, Callable, Tuple, Pattern, Any, Dict, Awaitable
@@ -124,17 +125,22 @@ class HTTPXMock:
         :param match_headers: HTTP headers identifying the request(s) to match. Must be a dictionary.
         :param match_content: Full HTTP body identifying the request(s) to match. Must be bytes.
         """
-        response = httpx.Response(
-            status_code=status_code,
-            extensions={"http_version": http_version.encode("ascii")},
-            headers=headers,
-            json=json,
-            content=content,
-            text=text,
-            html=html,
-            stream=stream,
-        )
-        self.add_callback(lambda request: response, **matchers)
+
+        json = copy.deepcopy(json) if json is not None else None
+
+        def response_callback(request: httpx.Request) -> httpx.Response:
+            return httpx.Response(
+                status_code=status_code,
+                extensions={"http_version": http_version.encode("ascii")},
+                headers=headers,
+                json=json,
+                content=content,
+                text=text,
+                html=html,
+                stream=stream,
+            )
+
+        self.add_callback(response_callback, **matchers)
 
     def add_callback(
         self,
